**Marginal Contribution Nets: A Compact Representation Scheme for Coalitional Games. 2005.**

Leong, Samuel. Shoham, Yoav. Standford University

Marginal Contribution Nets were employed to build a Shapley Value that runs at polynomial time used in the library. Not Allowed to provide a digital copy without permission. 

**Using the Shapley Value to Analyze Algorithm Portfolios. 2016.**

Frechette, Alexandre. Kotthoff, Lars. Michalak, Tomasz. Rahwan, Talal. Hoos, Holger H. Leyton-Brown, Kevin. University of Columbia, University of Wyoming, University of Warsaw, Masdar Institute of Science and Technology, 5Universiteit Leiden, University of British Columbia.

The paper that inspired the creation of this library. It explains how to set up algorithm portoflios into coalition games to be evaluated by the Shapley Value.

**Quantifying Algorithmic Improvements over Time. 2018.**

Kotthoff, Lars. Frechette, Alexandre. Michalak, Tomasz. Rahwan, Talal. Hoos, Holger H. Leyton-Brown, Kevin. University of Wyoming, University of Columbia, University of Warsaw, Masdar Institute of Science and Technology, 5Universiteit Leiden, University of British Columbia.

The article was used to build the Temporal Shapley Value library function.

